@@ -2,14 +2,20 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .stock import *
+
+from . import stock
 
 
 def register():
     Pool.register(
-        Move,
-        SplitMoveStart,
+        stock.Move,
+        stock.SplitMoveStart,
+        stock.ShipmentInReturn,
+        stock.ShipmentOut,
+        stock.ShipmentInternal,
+        stock.SplitShipmentStart,
         module='stock_split', type_='model')
     Pool.register(
-        SplitMove,
+        stock.SplitMove,
+        stock.SplitShipment,
         module='stock_split', type_='wizard')
