@@ -1,10 +1,10 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, fields
-from trytond.wizard import Wizard, StateView, StateTransition, Button
-from trytond.pyson import Eval
 from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval
 from trytond.transaction import Transaction
+from trytond.wizard import Button, StateTransition, StateView, Wizard
 
 
 class Move(metaclass=PoolMeta):
@@ -25,7 +25,7 @@ class Move(metaclass=PoolMeta):
     def split_wizard(cls, moves):
         pass
 
-    def split(self, quantity, uom, count=None):
+    def split(self, quantity, unit, count=None):
         """
         Split the move into moves of quantity.
         If count is not defined, the move will be split until the remainder is
@@ -36,7 +36,7 @@ class Move(metaclass=PoolMeta):
         Uom = pool.get('product.uom')
 
         moves = [self]
-        remainder = Uom.compute_qty(self.uom, self.quantity, uom)
+        remainder = Uom.compute_qty(self.unit, self.quantity, unit)
         if remainder <= quantity:
             return moves
         state = self.state
@@ -45,7 +45,7 @@ class Move(metaclass=PoolMeta):
                 })
         self.write([self], {
                 'quantity': quantity,
-                'uom': uom.id,
+                'unit': unit.id,
                 })
         remainder -= quantity
         if count:
@@ -55,18 +55,18 @@ class Move(metaclass=PoolMeta):
             with Transaction().set_context(_stock_move_split=True):
                 moves.extend(self.copy([self], {
                             'quantity': quantity,
-                            'uom': uom.id,
+                            'unit': unit.id,
                             }))
             remainder -= quantity
             if count:
                 count -= 1
-        remainder = uom.round(remainder)
+        remainder = unit.round(remainder)
         assert remainder >= 0
         if remainder:
             with Transaction().set_context(_stock_move_split=True):
                 moves.extend(self.copy([self], {
                             'quantity': remainder,
-                            'uom': uom.id,
+                            'unit': unit.id,
                         }))
         self.write(moves, {
                 'state': state,
@@ -78,23 +78,15 @@ class SplitMoveStart(ModelView):
     'Split Move'
     __name__ = 'stock.move.split.start'
     count = fields.Integer('Counts', help='The limit number of moves.')
-    quantity = fields.Float('Quantity', required=True,
-        digits=(16, Eval('unit_digits', 2)),
-        depends=['unit_digits'])
-    uom = fields.Many2One('product.uom', 'Uom', required=True,
+    quantity = fields.Float("Quantity", digits='unit', required=True)
+    unit = fields.Many2One(
+        'product.uom', "Unit", required=True,
         domain=[
             ('category', '=', Eval('uom_category')),
-            ],
-        depends=['uom_category'])
-    unit_digits = fields.Integer('Unit Digits', readonly=True)
-    uom_category = fields.Many2One('product.uom.category', 'Uom Category',
-        readonly=True)
-
-    @fields.depends('uom')
-    def on_change_with_unit_digits(self):
-        if self.uom:
-            return self.uom.digits
-        return 2
+            ])
+    uom_category = fields.Many2One(
+        'product.uom.category', "UoM Category", readonly=True,
+        help="The category of Unit of Measure.")
 
 
 class SplitMove(Wizard):
@@ -109,14 +101,13 @@ class SplitMove(Wizard):
 
     def default_start(self, fields):
         return {
-            'uom': self.record.uom.id,
-            'unit_digits': self.record.unit_digits,
-            'uom_category': self.record.uom.category.id,
+            'unit': self.record.unit.id,
+            'uom_category': self.record.unit.category.id,
             }
 
     def transition_split(self):
         self.record.split(
-            self.start.quantity, self.start.uom, self.start.count)
+            self.start.quantity, self.start.unit, self.start.count)
         return 'end'
 
 
@@ -204,6 +195,5 @@ class SplitShipmentStart(ModelView):
     moves = fields.Many2Many(
         'stock.move', None, None, "Moves",
         domain=[('id', 'in', Eval('domain_moves'))],
-        depends=['domain_moves'],
         help="The selected moves will be sent in the new shipment.")
     domain_moves = fields.Many2Many('stock.move', None, None, "Domain Moves")
